@@ -76,18 +76,6 @@ class AssistantBase(object):
 
         return self.name == leaf_name
 
-    def _dot_devassistant_create(self, directory, **kwargs):
-        self._dot_devassistant_path = os.path.join(directory, '.devassistant')
-        f = open(self._dot_devassistant_path, 'w')
-        # write path to this subassistant
-        path = []
-        i = 0
-        while settings.SUBASSISTANT_N_STRING.format(i) in kwargs:
-            path.append(kwargs[settings.SUBASSISTANT_N_STRING.format(i)])
-            i += 1
-        f.write('subassistant_path={0}'.format(' '.join(path)))
-        f.close()
-
     def errors(self, **kwargs):
         """Checks whether the command is doable, also checking the arguments
         passed as kwargs. These are supposed to be non-recoverable problems,
