@@ -4,7 +4,9 @@ import pytest
 from devassistant import exceptions
 from devassistant import settings
 from devassistant.assistants import yaml_assistant
+from devassistant.assistants import snippet
 from devassistant.command_helpers import ClHelper, RPMHelper, YUMHelper
+from devassistant.yaml_snippet_loader import YamlSnippetLoader
 
 # hook app testing logging
 from test.logger import TestLoggingHandler
@@ -18,46 +20,20 @@ class TestYamlAssistant(object):
         self.tlh = TestLoggingHandler.create_fresh_handler()
 
         self.ya2 = yaml_assistant.YamlAssistant()
+        self.ya2._files = {}
         self.ya2._run = [{'if $ide':
                             [{'if ls /notachance': [{'log_d': 'ifif'}]},
                              {'else': [{'log_d': 'ifelse'}]}]},
                          {'else': [{'log_d': 'else'}]}]
 
-    @pytest.mark.parametrize(('comm', 'arg_dict', 'result'), [
-        ('ls -la', {}, 'ls -la'),
-        ('touch $foo ${bar} $baz', {'foo': 'a', 'bar': 'b'}, 'touch a b $baz'),
-        ('cp *first second', {}, 'cp {0}/f/g second'.format(template_dir)),
-        ('cp *{first} *{nothing}', {}, 'cp %s/f/g *{nothing}' % (template_dir)),
-        ('cp *{first} $foo', {'foo': 'a'}, 'cp {0}/f/g a'.format(template_dir)),
-    ])
-    def test_format(self, comm, arg_dict, result):
-        assert self.ya._format(comm, **arg_dict) == result
-
-    def test_format_handles_bool(self):
-        # If command is false/true in yaml file, it gets coverted to False/True
-        # which is bool object. format should handle this.
-        assert self.ya._format(True) == 'true'
-        assert self.ya._format(False) == 'false'
-
-    def test_errors_pass(self):
-        self.ya._fail_if = [{'cl': 'false'}, {'cl': 'grep'}]
-        assert not self.ya.errors()
-
-    def test_errors_fail(self):
-        self.ya._fail_if = [{'cl': 'false'}, {'cl': 'true'}]
-        assert self.ya.errors() == ['Cannot proceed because command returned 0: true']
-
-    def test_errors_unknow_action(self):
-        self.ya._fail_if = [{'foobar': 'not an action'}]
-        assert not self.ya.errors()
-        assert self.tlh.msgs == [('WARNING', 'Unknown action type foobar, skipping.')]
-
     # TODO: refactor to also test _dependencies_section alone
     def test_dependencies(self):
         self.ya._dependencies = [{'default': [{'rpm': ['foo', '@bar', 'baz']}]}]
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, True).one_by_one()
         flexmock(YUMHelper).should_receive('is_group_installed').and_return(False)
         flexmock(YUMHelper).should_receive('install').with_args('foo', '@bar').and_return(True)
+        # TODO: rpmhelper is used for checking whether a group was installed - fix
+        flexmock(RPMHelper).should_receive('was_rpm_installed').and_return(True, True).one_by_one()
         self.ya.dependencies()
 
     def test_dependencies_uses_non_default_section_on_param(self):
@@ -65,12 +41,14 @@ class TestYamlAssistant(object):
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, False).one_by_one()
         flexmock(YUMHelper).should_receive('install').with_args('foo').and_return(True)
         flexmock(YUMHelper).should_receive('install').with_args('bar').and_return(True)
+        flexmock(RPMHelper).should_receive('was_rpm_installed').and_return(True)
         self.ya.dependencies(a=True)
 
     def test_dependencies_does_not_use_non_default_section_when_param_not_present(self):
         self.ya._dependencies = [{'default': [{'rpm': ['foo']}]}, {'_a': [{'rpm': ['bar']}]}]
         flexmock(RPMHelper).should_receive('is_rpm_installed').and_return(False, False).one_by_one()
         flexmock(YUMHelper).should_receive('install').with_args('foo').and_return(True)
+        flexmock(RPMHelper).should_receive('was_rpm_installed').and_return(True)
         self.ya.dependencies()
 
     def test_run_pass(self):
@@ -99,34 +77,42 @@ class TestYamlAssistant(object):
         section = self.ya._get_section_to_run(section='run', kwargs_override=True, foo=True)
         assert section is self.ya._run_foo
 
+    def test_get_section_to_run_runs_with_None_parameter(self):
+        self.ya._run = [{'cl': 'ls'}]
+        self.ya._run_foo = [{'cl': 'pwd'}]
+        section = self.ya._get_section_to_run(section='run', kwargs_override=True, foo=None)
+        assert section is self.ya._run_foo
+
     def test_run_runs_in_foreground_if_asked(self):
         self.ya._run = [{'cl_f': 'ls'}]
         flexmock(ClHelper).should_receive('run_command').with_args('ls', True, False)
         self.ya.run(foo='bar')
 
     def test_run_logs_command_at_debug(self):
-        self.ya._run = [{'cl': 'ls'}]
+        # previously, this test used 'ls', but that is in different locations on different
+        # distributions (due to Fedora's usrmove), so use something that should be common
+        self.ya._run = [{'cl': 'id'}]
         self.ya.run(foo='bar')
-        assert self.tlh.msgs == [('DEBUG', settings.COMMAND_LOG_STRING.format(cmd='/usr/bin/ls'))]
+        assert self.tlh.msgs == [('DEBUG', settings.COMMAND_LOG_STRING.format(cmd='/usr/bin/id'))]
 
     def test_run_logs_command_at_info_if_asked(self):
-        self.ya._run = [{'cl_i': 'ls'}]
+        self.ya._run = [{'cl_i': 'id'}]
         self.ya.run(foo='bar')
-        assert self.tlh.msgs == [('INFO', settings.COMMAND_LOG_STRING.format(cmd='/usr/bin/ls'))]
+        assert self.tlh.msgs == [('INFO', settings.COMMAND_LOG_STRING.format(cmd='/usr/bin/id'))]
 
     def test_log(self):
-        self.ya._fail_if = [{'log_w': 'foo!'}]
-        self.ya.errors()
+        self.ya._run = [{'log_w': 'foo!'}]
+        self.ya.run()
         assert self.tlh.msgs == [('WARNING', 'foo!')]
 
     def test_log_wrong_level(self):
-        self.ya._fail_if = [{'log_b': 'bar'}]
-        self.ya.errors()
+        self.ya._run = [{'log_b': 'bar'}]
+        self.ya.run()
         assert self.tlh.msgs == [('WARNING', 'Unknown logging command log_b with message bar')]
 
     def test_log_formats_message(self):
-        self.ya._fail_if = [{'log_i': 'this is $how cool'}]
-        self.ya.errors(how='very')
+        self.ya._run = [{'log_i': 'this is $how cool'}]
+        self.ya.run(how='very')
         assert self.tlh.msgs == [('INFO', 'this is very cool')]
 
     def test_run_if_nested_else(self):
@@ -157,3 +143,11 @@ class TestYamlAssistant(object):
         self.ya._run = [{'$foo': 'ls spam/spam/spam'}, {'log_i': '$foo'}]
         self.ya.run()
         assert ('INFO', '') in self.tlh.msgs
+
+    def test_run_snippet(self):
+        self.ya._run = [{'snippet': 'mysnippet'}]
+        flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
+                                    with_args('mysnippet').\
+                                    and_return(snippet.Snippet('mysnippet.yaml', {'run': [{'log_i': 'spam'}]}))
+        self.ya.run()
+        assert ('INFO', 'spam') in self.tlh.msgs
